@@ -20,6 +20,7 @@ from difflib import get_close_matches
 
 import dateutil.parser
 from collections import namedtuple
+import json
 
 
 class Receipt(object):
@@ -125,7 +126,7 @@ class Receipt(object):
 
             for word in ignored_words:
                 parse_stop = fnmatch.fnmatch(article_name, f"*{word}*")
-                if parse_stop: return items
+                if parse_stop: continue
 
             items.append(item(article_name, article_sum))
 
@@ -163,3 +164,18 @@ class Receipt(object):
                 sum_float = re.search(self.config.sum_format, sum_line)
                 if sum_float:
                     return sum_float.group(0)
+
+
+    def to_json(self):
+        """
+        :return: json
+            Convert Receipt object to json
+        """
+        object_data = {
+            "market": self.market,
+            "date": self.date,
+            "sum": self.sum,
+            "items": self.items,
+            "lines": self.lines
+        }
+        return json.dumps(object_data)
\ No newline at end of file
